/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "frame.h"
#include "display/symbol.h"
#include "rpg/world/map.h"
#include "game.h"

char_t FRAME_BUFFER[FRAME_HEIGHT * FRAME_WIDTH];
uint8_t FRAME_COLOR[FRAME_HEIGHT * FRAME_WIDTH];

void frameInit() {
  memset(FRAME_BUFFER, ' ', FRAME_HEIGHT * FRAME_WIDTH);
}

void frameUpdate() {
  // Draw buffer
  entity_t *ent;
  tile_t tile;
  uint32_t i;

  map_t *map = GAME.currentMap;
  if(map == NULL) {
    memset(FRAME_BUFFER, ' ', FRAME_HEIGHT * FRAME_WIDTH);
    return;
  }

  // Update frame buffer. I can definitely optimize this.
  i = 0;
  for(uint16_t y = 0; y < FRAME_HEIGHT; y++) {
    for(uint16_t x = 0; x < FRAME_WIDTH; x++) {
      if(x >= map->width || y >= map->height) {
        FRAME_COLOR[i] = COLOR_BLACK;
        FRAME_BUFFER[i++] = ' ';
        continue;
      }

      // Entity?
      ent = mapEntityGetByPosition(map, x, y);
      if(ent != NULL) {
        FRAME_COLOR[i] = symbolGetColorByEntity(ent);
        FRAME_BUFFER[i++] = symbolGetCharByEntity(ent);
        continue;
      }

      // Tile?
      tile = mapTileGetByPosition(map, x, y, 0);
      FRAME_COLOR[i] = symbolGetColorByTile(tile);
      FRAME_BUFFER[i++] = symbolGetCharByTile(tile);
    }
  }
}