/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "rpg/entity/entity.h"
#include "rpg/world/tile.h"
#include "display/color.h"

/**
 * Returns the symbol for the given entity.
 * 
 * @param ent Entity to get the symbol for.
 * @return The symbol for the entity.
 */
char_t symbolGetCharByEntity(const entity_t *ent);

/**
 * Returns the symbol for the given tile.
 * 
 * @param tile Tile to get the symbol for.
 * @return The symbol for the tile.
 */
char_t symbolGetCharByTile(const tile_t tile);

/**
 * Returns the color for the given entity.
 * 
 * @param ent Entity to get the color for.
 * @return The color for the entity.
 */
uint8_t symbolGetColorByEntity(const entity_t *ent);

/**
 * Returns the color for the given tile.
 * 
 * @param tile Tile to get the color for.
 * @return The color for the tile.
 */
uint8_t symbolGetColorByTile(const tile_t tile);