/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "display/display.h"
#include "display/frame.h"
#include "display/termcolor.h"
#include "assert/assert.h"

void displayInit() {
  frameInit();
}

void displayUpdate() {
  frameUpdate();

  // Print clear and return to top left
  printf("\033[2J\033[1;1H");
  int32_t i = 0;
  const char_t *color;
  for(uint16_t y = 0; y < FRAME_HEIGHT; y++) {
    for(uint16_t x = 0; x < FRAME_WIDTH; x++) {
      switch(FRAME_COLOR[i]) {
        case COLOR_BLACK:
          color = TERM_COLOR_BLACK;
          break;
        
        case COLOR_WHITE:
          color = TERM_COLOR_WHITE;
          break;

        case COLOR_RED:
          color = TERM_COLOR_RED;
          break;

        case COLOR_GREEN:
          color = TERM_COLOR_GREEN;
          break;

        case COLOR_BLUE:
          color = TERM_COLOR_BLUE;
          break;

        case COLOR_YELLOW:
          color = TERM_COLOR_YELLOW;
          break;

        case COLOR_MAGENTA:
          color = TERM_COLOR_MAGENTA;
          break;

        case COLOR_CYAN:
          color = TERM_COLOR_CYAN;
          break;

        default:
          assertUnreachable("Invalid color.");
      }

      printf(
        "%s%c",
        color,
        FRAME_BUFFER[i]
      );
      i++;
    }

    printf("\r\n");
  }

  printf(TERM_COLOR_RESET);
}

void displayDispose() {
}